Module scope

Module scope 

Structs

BoolType
CommonClass
CommonScope
Constructor
Executable constructor declaration.
Field
Function
IntType
Predicate
RealType
StringType

Traits

Class
Class-specific API surface layered on top of type and scope behavior.
Scope
Type

Functions

arith_type
Returns the resulting numeric type for arithmetic terms.
get_type_by_path
is_assignable_from
Returns whether a value of source type can be assigned to target.