get_predicate_by_path

Function get_predicate_by_path 

pub fn get_predicate_by_path(
    scope: &dyn Scope,
    path: &[String],
) -> Result<Rc<Predicate>, RiddleError>
Resolves a predicate by path.

All segments except the last are resolved as a type path via get_type_by_path. The last segment is then looked up as a predicate within the resolved class type.

Errors

Returns: