get_type_by_path

Function get_type_by_path 

pub fn get_type_by_path(
    scope: &dyn Scope,
    path: &[String],
) -> Result<Rc<dyn Type>, RiddleError>
Resolves a type by a dotted path-like sequence of names.

The first segment is looked up in the provided Scope, and each subsequent segment is resolved as a nested type of the previous class.

Errors

Returns: