Predicate

Struct Predicate 

pub struct Predicate { /* private fields */ }
Predicate type and runtime behavior.

Predicates can be instantiated as atoms, can inherit from parent predicates, and execute associated statements for each atom invocation.

Implementations

Source

impl Predicate

pub fn new( core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>, predicate: PredicateDef, ) -> Rc<Self>

Creates a predicate from its parsed definition.

pub fn parents(&self) -> &[Vec<String>]

pub fn args(&self) -> &[(Vec<String>, String)]

pub fn statements(&self) -> &[Statement]

pub fn new_atom( self: Rc<Self>, fact: bool, args: HashMap<String, Rc<dyn Var>>, ) -> Rc<Atom>

Registers a new atom for this predicate and all declared parent predicates.

pub fn call(self: Rc<Self>, atom: Rc<Atom>) -> Result<(), RiddleError>

Executes predicate statements against a concrete atom.

pub fn atoms(&self) -> Vec<Rc<Atom>>