pub struct CommonCore { /* private fields */ }Implementations
Sourceimpl CommonCore
impl CommonCore
Sourcepub fn new(core: Weak<dyn Core>) -> Rc<Self>
pub fn new(core: Weak<dyn Core>) -> Rc<Self>
Creates a new shared core with a root scope and environment.
The core is initialized with the builtin primitive types:
bool, int, real, and string.
Sourcepub fn read(&self, riddle: &str) -> Result<(), RiddleError>
pub fn read(&self, riddle: &str) -> Result<(), RiddleError>
Parses and executes a RiDDLe problem in this core context.
The parsed problem metadata is registered in the current scope, then each statement is executed in order using this core scope and environment.
Returns an error if parsing or execution fails.