pub struct CommonScope { /* private fields */ }Expand description
Generic hierarchical scope used to resolve fields, methods, nested types, and predicates.
Implementations
Sourceimpl CommonScope
impl CommonScope
Sourcepub fn new(core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>) -> Self
pub fn new(core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>) -> Self
Creates an empty scope with an optional parent scope.
Sourcepub fn from_class(
core: Weak<dyn Core>,
scope: Option<Weak<dyn Scope>>,
class_scope: Weak<dyn Scope>,
class: ClassDef,
) -> Rc<Self>
pub fn from_class( core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>, class_scope: Weak<dyn Scope>, class: ClassDef, ) -> Rc<Self>
Builds a scope populated from a class definition.
Sourcepub fn from_costructor(
core: Weak<dyn Core>,
scope: Option<Weak<dyn Scope>>,
constructor: ConstructorDef,
) -> Self
pub fn from_costructor( core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>, constructor: ConstructorDef, ) -> Self
Builds a local scope for constructor arguments.
Sourcepub fn from_method(
core: Weak<dyn Core>,
scope: Option<Weak<dyn Scope>>,
method: MethodDef,
) -> Self
pub fn from_method( core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>, method: MethodDef, ) -> Self
Builds a local scope for method arguments.
Sourcepub fn from_predicate(
core: Weak<dyn Core>,
scope: Option<Weak<dyn Scope>>,
predicate: PredicateDef,
) -> Self
pub fn from_predicate( core: Weak<dyn Core>, scope: Option<Weak<dyn Scope>>, predicate: PredicateDef, ) -> Self
Builds a local scope for predicate arguments.
Sourcepub fn add_problem(&self, problem: ProblemDef)
pub fn add_problem(&self, problem: ProblemDef)
Merges problem-level declarations into this scope.